OC.L10N.register(
    "text",
    {
    "No file was uploaded" : "ವರ್ಗಾವಣೆಗೆ ﻿ಯಾವುದೇ ಕಡತಗಳು ಕಂಡುಬಂದಿಲ್ಲ",
    "Missing a temporary folder" : "ತಾತ್ಕಾಲಿಕ ಕಡತಕೋಶ ದೊರೆಕುತ್ತಿಲ್ಲ",
    "guest" : "ಅತಿಥಿ",
    "Saved" : "﻿ಉಳಿಸಿದ",
    "Info" : "Info",
    "Warning" : "﻿ಎಚ್ಚರಿಕೆ",
    "Edit" : "ಸಂಪಾದಿಸು"
},
"nplurals=2; plural=(n > 1);");
